@@ -1,7 +1,7 @@
 
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 3.6 2002/01/29 03:05:54 bkorb Exp $
+ *  $Id: defDirect.c,v 1.21 2002/07/07 20:41:16 bkorb Exp $
  *  This module processes definition file directives.
  */
 
@@ -705,6 +705,37 @@ doDir_line( char* pzArg, char* pzScan )
 }
 
 
+/*=directive option
+ *
+ *  arg:  opt-name [ <text> ]
+ *
+ *  text:
+ *
+ *  This directive will pass the option name and associated text to the
+ *  AutoOpts optionLoadLine routine (@pxref{optionLoadLine}).  The option text
+ *  may span multiple lines by continuing them with a backslash.
+ *  The backslash/newline pair will be replaced with two space characters.
+ *  This directive may be used to set a search path for locating template files
+ *  For example, this:
+ *
+ *  @example
+ *    #option templ-dirs $ENVVAR/dirname
+ *  @end example
+ *  @noindent
+ *  will direct autogen to use the @code{ENVVAR} environment variable to find
+ *  a directory named @code{dirname} that (may) contain templates.  Since these
+ *  directories are searched in most recently supplied first order, search
+ *  directories supplied in this way will be searched before any supplied on
+ *  the command line.
+=*/
+STATIC char*
+doDir_option( char* pzArg, char* pzScan )
+{
+    optionLoadLine( &autogenOptions, pzArg );
+    return pzScan;
+}
+
+
 /*=directive pragma
  *
  *  dummy:  pragma directives are ignored.
