@@ -6,9 +6,9 @@
  * Maintainer:	       Gary V. Vaughan <gvv@techie.com>
  * Created:	       Fri Nov 13 11:23:23 1998
  * Last Modified:      Thu Apr  6 02:20:12 2000
- *            by:      Gary V. Vaughan <gvv@techie.com>
+ *            by: bkorb
  * ---------------------------------------------------------------------
- * @(#) $Id: snprintfv.c,v 1.6 2001/08/12 03:07:03 bkorb Exp $
+ * @(#) $Id: snprintfv.c,v 1.7 2002/06/20 22:58:38 bkorb Exp $
  * ---------------------------------------------------------------------
  */
 
@@ -233,23 +233,15 @@ parser_init (pparser)
 {
     memset(pparser, 0, sizeof(printfv_parser));
     pparser->state = SNV_STATE_BEGIN;
-
-    return pparser;
-}
-
-#if 0 /* Not actually used right now... */
-/* Create, initialise and return a new printfv_parser structure. */
-static inline printfv_parser*
-parser_new PARAMS((void))
-{
-    printfv_parser *pparser;
-
-    pparser = snv_new(printfv_parser, 1);
-    pparser = parser_init(pparser);
-
-    return pparser;
-}
+#ifndef INT_MIN
+	{
+		extern int snv_init_min_max( );
+		snv_init_min_max();
+	}
 #endif
+    return pparser;
+}
+
 
 static void
 parser_delete (parser)
